@@ -20,7 +20,7 @@ use vars qw( $CACHE $UPDATING_CACHE );
 
 @ISA = qw(Exporter);
 
-$VERSION = sprintf "%d.%02d%02d", q/1.50.2/ =~ /(\d+)/g;
+$VERSION = sprintf "%d.%02d%02d", q/1.51.0/ =~ /(\d+)/g;
 $DEBUG = 0;
 
 #-------------------------------------------------------------------------------
@@ -293,8 +293,8 @@ sub _OPEN_FILE_HANDLE
 
   dprint "Calling \"$filter_command\" to decompress file \"$file_name\".";
 
-  use vars qw(*OLDSTDERR);
-  open OLDSTDERR,">&STDERR" or die "Can't save STDERR: $!\n";
+  my $oldstderr;
+  open $oldstderr,">&STDERR" or die "Can't save STDERR: $!\n";
   open STDERR,">" . File::Spec->devnull()
     or die "Can't redirect STDERR to " . File::Spec->devnull() . ": $!\n";
 
@@ -305,7 +305,7 @@ sub _OPEN_FILE_HANDLE
 
   binmode $file_handle;
 
-  open STDERR,">&OLDSTDERR" or die "Can't restore STDERR: $!\n";
+  open STDERR, '>&', $oldstderr or die "Can't restore STDERR: $!\n";
 
   if (eof($file_handle))
   {
@@ -390,6 +390,8 @@ sub _GET_FILE_TYPE
   # See "magic" on unix systems for details on how to identify file types
   return 'bzip2' if substr($test_chars, 0, 3) eq 'BZh';
   return 'bzip' if substr($test_chars, 0, 2) eq 'BZ';
+  return 'xz' if substr($test_chars, 1, 4) eq '7zXZ';
+  return 'lzip' if substr($test_chars, 0, 4) eq 'LZIP';
 #  return 'zip' if substr($test_chars, 0, 2) eq 'PK' &&
 #    ord(substr($test_chars,3,1)) == 0003 && ord(substr($test_chars,4,1)) == 0004;
   return 'gzip' if
@@ -483,7 +485,7 @@ sub _IS_COMPRESSED_TYPE
   
   local $" = '|';
 
-  my @types = qw( gzip bzip bzip2 compress );
+  my @types = qw( gzip bzip bzip2 xz lzip compress );
   my $file_type_pattern = "(@types)";
 
   return $file_type =~ /^$file_type_pattern$/;
@@ -628,12 +630,37 @@ sub _DO_DECOMPRESSION
 # 1000 characters because the body may have foreign binary-like characters
 sub _IS_BINARY_MAILBOX
 {
-  my $data_length;
-  $data_length = index(${$_[0]},"\n\n");
-  $data_length = index(${$_[0]},"\r\n\r\n") if $data_length == -1;
-  $data_length = CORE::length(${$_[0]}) if $data_length == -1;
+  my ($start, $data_length);
 
-  my $bin_length = substr(${$_[0]},0,$data_length) =~ tr/[\t\n\x20-\x7e]//c;
+  # Unix line endings
+  {
+    $start = 0;
+
+    # Handle newlines at the start
+    while (index(${$_[0]}, "\n\n", $start) == $start) {
+      $start += 2;
+    }
+
+    $data_length = index(${$_[0]}, "\n\n", $start) - $start;
+  }
+
+  # If we didn't succeed with Unix line endings, try DOS line endings
+  if ($data_length == -1)
+  {
+    # Handle newlines at the start
+    $start = 0;
+
+    while (index(${$_[0]}, "\r\n\r\n", $start) == $start) {
+      $start += 4;
+    }
+
+    $data_length = index(${$_[0]}, "\r\n\r\n", $start) - $start;
+  }
+
+  # Didn't find any kind of empty line. Use the whole buffer.
+  $data_length = CORE::length(${$_[0]}) - $start if $data_length == -1;
+
+  my $bin_length = substr(${$_[0]}, $start ,$data_length) =~ tr/[\t\n\x20-\x7e]//c;
 
   my $non_bin_length = $data_length - $bin_length;
 
@@ -854,7 +881,7 @@ sub _GET_HEADER_FIELD
 
   # Avoid perl 5.6 bug which causes spurious warning even though $email_header
   # is defined.
-  local $^W = 0 if $] >= 5.006 && $] < 5.8;
+  local $^W = 0 if $] >= 5.006 && $] < 5.008;
 
   if ($header_name =~ /^From$/i &&
     $$email_header =~ /^((?:From\s|X-From-Line:|X-Draft-From:).*$endline(\s.*$endline)*)/im)
@@ -894,7 +921,8 @@ Mail::Mbox::MessageParser - A fast and simple mbox folder reader
 
   use Mail::Mbox::MessageParser;
 
-  my $file_name = 'mail/saved-mail';
+  # Compression support
+  my $file_name = 'mail/saved-mail.xz';
   my $file_handle = new FileHandle($file_name);
 
   # Set up cache. (Not necessary if enable_cache is false.)
@@ -982,11 +1010,10 @@ file using the file name. You should always pass the file name if you have it,
 so that the parser can cache the mailbox information.
 
 This module will automatically decompress the mailbox as necessary. If a
-filename is available but the file handle is undef, the module will call
-either bzip2, or gzip to decompress the file in memory if the filename
-ends with .tz, .bz2, or .gz, respectively. If the file handle is defined, it
-will detect the type of compression and apply the correct decompression
-program.
+filename is available but the file handle is undef, the module will call bzip,
+bzip2, gzip, lzip, xz to decompress the file in memory if the filename ends
+with the appropriate suffix. If the file handle is defined, it will detect the
+type of compression and apply the correct decompression program.
 
 The Cache, Grep, or Perl implementation of the parser will be loaded,
 whichever is most appropriate. For example, the first time you use caching,
